Index: LightsManager.cpp
===================================================================
--- LightsManager.cpp	(revision 28064)
+++ LightsManager.cpp	(working copy)
@@ -14,7 +14,14 @@
 #include "GameManager.h"
 #include "CommonMetrics.h"
 #include "Style.h"
+#include <windows.h>
 
+bool prevstate = false;
+extern HANDLE hSerial;
+DWORD dwBytesWritten;
+char zero[4] = "0\r\n";
+char one[4] = "1\r\n";
+
 const RString DEFAULT_LIGHTS_DRIVER = "SystemMessage,Export";
 static Preference<RString> g_sLightsDriver( "LightsDriver", "" ); // "" == DEFAULT_LIGHTS_DRIVER
 Preference<float>	g_fLightsFalloffSeconds( "LightsFalloffSeconds", 0.1f );
@@ -205,6 +212,7 @@
 		m_fTestAutoCycleCurrentIndex = fmodf( m_fTestAutoCycleCurrentIndex, NUM_CabinetLight*100 );
 	}
 
+	bool anded = false;
 	switch( m_LightsMode )
 	{
 	case LIGHTSMODE_ATTRACT:
@@ -292,13 +300,25 @@
 	case LIGHTSMODE_DEMONSTRATION:
 	case LIGHTSMODE_GAMEPLAY:
 		FOREACH_CabinetLight( cl )
+		{
 			m_LightsState.m_bCabinetLights[cl] = m_fSecsLeftInCabinetLightBlink[cl] > 0;
+			anded |= m_LightsState.m_bCabinetLights[cl];
+		}
+		if(anded == prevstate)
+			break;
+		if(anded) {
+			WriteFile(hSerial, one, 1, &dwBytesWritten, NULL);
+		} else {
+			WriteFile(hSerial, zero, 1, &dwBytesWritten, NULL);
+		}
+		prevstate = anded;
 		break;
 	case LIGHTSMODE_STAGE:
 	case LIGHTSMODE_ALL_CLEARED:
 		{
 			FOREACH_CabinetLight( cl )
 				m_LightsState.m_bCabinetLights[cl] = true;
+			WriteFile(hSerial, one, 1, &dwBytesWritten, NULL);
 		}
 		break;
 	case LIGHTSMODE_TEST_AUTO_CYCLE:
Index: StepMania.cpp
===================================================================
--- StepMania.cpp	(revision 28064)
+++ StepMania.cpp	(working copy)
@@ -81,6 +81,7 @@
 
 static Preference<bool> g_bAllowMultipleInstances( "AllowMultipleInstances", false );
 
+HANDLE hSerial;
 
 void StepMania::GetPreferredVideoModeParams( VideoModeParams &paramsOut )
 {
@@ -279,6 +280,8 @@
  * these may still be NULL. */
 void ShutdownGame()
 {
+	CloseHandle(hSerial); // Kill the serial port
+
 	/* First, tell SOUNDMAN that we're shutting down.  This signals sound drivers to
 	 * stop sounds, which we want to do before any threads that may have started sounds
 	 * are closed; this prevents annoying DirectSound glitches and delays. */
@@ -940,6 +943,7 @@
 		runmode = RunMode_ExportLuaInformation;
 
 
+
 	/* Set up arch hooks first.  This may set up crash handling. */
 	HOOKS = ArchHooks::Create();
 	HOOKS->Init();
@@ -982,6 +986,35 @@
 
 	WriteLogHeader();
 
+	RString serialport = "COM1";
+	if( GetCommandlineArgument("serialport", &serialport, 0))
+		LOG->Info(RString("\n\nSerial port ") + serialport + RString(" selected by commandline option\n\n"));
+	/*  Try to open the serial port */
+	RString serialstring = "\\\\.\\" + serialport;
+	hSerial = CreateFile(serialstring.c_str(), GENERIC_READ | GENERIC_WRITE, 0, 0, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, 0);
+	if(hSerial==INVALID_HANDLE_VALUE){
+		if(GetLastError()==ERROR_FILE_NOT_FOUND){
+			LOG->Info("\n\n************ COM PORT NOT FOUND, LIGHTS WILL FAIL **********\n\n");
+
+		}
+		LOG->Info("\nSomething weird's happening with the serial port.\n");
+
+	} else {
+		LOG->Info("Opened serial port successfully.\n");
+	}
+	DCB dcbSerialParams = {0};
+	dcbSerialParams.DCBlength=sizeof(dcbSerialParams);
+	if (!GetCommState(hSerial, &dcbSerialParams)) {
+		//error getting state
+	}
+	dcbSerialParams.BaudRate=CBR_115200;
+	dcbSerialParams.ByteSize=8;
+	dcbSerialParams.StopBits=ONESTOPBIT;
+	dcbSerialParams.Parity=NOPARITY;
+	if(!SetCommState(hSerial, &dcbSerialParams)){
+		LOG->Info("Couldn't set serial port speed.\n");
+	}
+
 	/* Set up alternative filesystem trees. */
 	if( PREFSMAN->m_sAdditionalFolders.Get() != "" )
 	{
